@@ -12,6 +12,8 @@ import shelve
 import json
 import re
 
+from contextlib import closing # for Python2.6 compatibility
+
 import boto
 from boto.s3.key import Key
 import boto.glacier
@@ -21,7 +23,7 @@ from boto.exception import S3ResponseError
 from beefish import decrypt, encrypt_file
 import aaargh
 
-__version__ = "0.3.1"
+__version__ = "0.3.2"
 
 DEFAULT_LOCATION = "us-east-1"
 DEFAULT_DESTINATION = "s3"
@@ -191,7 +193,7 @@ class GlacierBackend:
 
 
     def upload(self, keyname, filename):
-        archive_id = self.vault.concurrent_create_archive_from_file(filename) # , keyname => second argument not on pypi yet
+        archive_id = self.vault.concurrent_create_archive_from_file(filename, keyname)
 
         # Storing the filename => archive_id data.
         with glacier_shelve() as d:
@@ -354,7 +356,7 @@ def backup(filename, destination=None, description=None, **kwargs):
 
     log.info("Compressing...")
     with tempfile.NamedTemporaryFile(delete=False) as out:
-        with tarfile.open(fileobj=out, mode="w:gz") as tar:
+        with closing(tarfile.open(fileobj=out, mode="w:gz")) as tar:
             tar.add(filename, arcname=arcname)
         outname = out.name
 
